fill

Function fill 

pub fn fill(access: Access<'_>, map: Map, x: u8, y: u8, w: u8, h: u8, tile: u8)
Put tile in every cell of a w by h rectangle.

Panics

If w or h is past SIDE, which would wrap over what was just written.