write

Function write 

pub fn write(access: Access<'_>, map: Map, x: u8, y: u8, src: TileGrid<'_>)
Copy src in with its top left at (x, y).

Panics

If src is wider or taller than SIDE, which would wrap over what was just written, or if it does not fit the data it was built from.